Index: /issm/trunk-jpl/packagers/linux/complete-issm-linux-binaries-matlab.sh
===================================================================
--- /issm/trunk-jpl/packagers/linux/complete-issm-linux-binaries-matlab.sh	(revision 27110)
+++ /issm/trunk-jpl/packagers/linux/complete-issm-linux-binaries-matlab.sh	(revision 27111)
@@ -6,5 +6,5 @@
 #
 # Normally, we would put this directly into the project configuration under 
-# 'Build' -> 'Excute shell', but becasue it is a bit more involved, it is a 
+# 'Build' -> 'Execute shell', but because it is a bit more involved, it is a 
 # good idea to version it.
 #
Index: /issm/trunk-jpl/packagers/linux/complete-issm-linux-binaries-python-2.sh
===================================================================
--- /issm/trunk-jpl/packagers/linux/complete-issm-linux-binaries-python-2.sh	(revision 27110)
+++ /issm/trunk-jpl/packagers/linux/complete-issm-linux-binaries-python-2.sh	(revision 27111)
@@ -6,5 +6,5 @@
 #
 # Normally, we would put this directly into the project configuration under 
-# 'Build' -> 'Excute shell', but becasue it is a bit more involved, it is a 
+# 'Build' -> 'Execute shell', but because it is a bit more involved, it is a 
 # good idea to version it.
 #
Index: /issm/trunk-jpl/packagers/linux/complete-issm-linux-binaries-python-3.sh
===================================================================
--- /issm/trunk-jpl/packagers/linux/complete-issm-linux-binaries-python-3.sh	(revision 27110)
+++ /issm/trunk-jpl/packagers/linux/complete-issm-linux-binaries-python-3.sh	(revision 27111)
@@ -6,5 +6,5 @@
 #
 # Normally, we would put this directly into the project configuration under 
-# 'Build' -> 'Excute shell', but becasue it is a bit more involved, it is a 
+# 'Build' -> 'Execute shell', but because it is a bit more involved, it is a 
 # good idea to version it.
 #
Index: /issm/trunk-jpl/packagers/linux/package-issm-linux-binaries-matlab.sh
===================================================================
--- /issm/trunk-jpl/packagers/linux/package-issm-linux-binaries-matlab.sh	(revision 27110)
+++ /issm/trunk-jpl/packagers/linux/package-issm-linux-binaries-matlab.sh	(revision 27111)
@@ -109,13 +109,4 @@
 fi
 
-echo "Moving PROJ assets to share/"
-if [ -d ${ISSM_DIR}/externalpackages/proj/install/share/proj ]; then
-	mkdir ${ISSM_DIR}/share 2> /dev/null
-	cp -R ${ISSM_DIR}/externalpackages/proj/install/share/proj ${ISSM_DIR}/share
-else
-	echo "PROJ not found"
-	exit 1
-fi
-
 echo "Moving libgfortran to lib/"
 cp ${LIBGFORTRAN} ${LIBGFORTRAN_DIST} 2> /dev/null
Index: /issm/trunk-jpl/packagers/mac/commit_for_signing-issm-mac-binaries-matlab.sh
===================================================================
--- /issm/trunk-jpl/packagers/mac/commit_for_signing-issm-mac-binaries-matlab.sh	(revision 27110)
+++ /issm/trunk-jpl/packagers/mac/commit_for_signing-issm-mac-binaries-matlab.sh	(revision 27111)
@@ -138,4 +138,6 @@
 	echo "Removing lock file from repository for signed packages"
 	svn update \
+		--trust-server-cert \
+		--non-interactive \
 		--username ${ISSM_BINARIES_REPO_USER} \
 		--password ${ISSM_BINARIES_REPO_PASS} \
@@ -156,4 +158,6 @@
 # If lock file exists, a signing build is still in process by JPL Cybersecurity
 svn update \
+	--trust-server-cert \
+	--non-interactive \
 	--username ${ISSM_BINARIES_REPO_USER} \
 	--password ${ISSM_BINARIES_REPO_PASS} \
@@ -214,4 +218,6 @@
 	sleep ${SIGNING_CHECK_PERIOD}
 	svn update \
+		--trust-server-cert \
+		--non-interactive \
 		--username ${ISSM_BINARIES_REPO_USER} \
 		--password ${ISSM_BINARIES_REPO_PASS} \
@@ -221,4 +227,6 @@
 		# Retrieve notarization lock file
 		svn update \
+			--trust-server-cert \
+			--non-interactive \
 			--username ${ISSM_BINARIES_REPO_USER} \
 			--password ${ISSM_BINARIES_REPO_PASS} \
Index: /issm/trunk-jpl/packagers/mac/commit_for_signing-issm-mac-binaries-python-2.sh
===================================================================
--- /issm/trunk-jpl/packagers/mac/commit_for_signing-issm-mac-binaries-python-2.sh	(revision 27110)
+++ /issm/trunk-jpl/packagers/mac/commit_for_signing-issm-mac-binaries-python-2.sh	(revision 27111)
@@ -138,4 +138,6 @@
 	echo "Removing lock file from repository for signed packages"
 	svn update \
+		--trust-server-cert \
+		--non-interactive \
 		--username ${ISSM_BINARIES_REPO_USER} \
 		--password ${ISSM_BINARIES_REPO_PASS} \
@@ -156,4 +158,6 @@
 # If lock file exists, a signing build is still in process by JPL Cybersecurity
 svn update \
+	--trust-server-cert \
+	--non-interactive \
 	--username ${ISSM_BINARIES_REPO_USER} \
 	--password ${ISSM_BINARIES_REPO_PASS} \
@@ -214,4 +218,6 @@
 	sleep ${SIGNING_CHECK_PERIOD}
 	svn update \
+		--trust-server-cert \
+		--non-interactive \
 		--username ${ISSM_BINARIES_REPO_USER} \
 		--password ${ISSM_BINARIES_REPO_PASS} \
@@ -221,4 +227,6 @@
 		# Retrieve notarization lock file
 		svn update \
+			--trust-server-cert \
+			--non-interactive \
 			--username ${ISSM_BINARIES_REPO_USER} \
 			--password ${ISSM_BINARIES_REPO_PASS} \
Index: /issm/trunk-jpl/packagers/mac/commit_for_signing-issm-mac-binaries-python-3.sh
===================================================================
--- /issm/trunk-jpl/packagers/mac/commit_for_signing-issm-mac-binaries-python-3.sh	(revision 27110)
+++ /issm/trunk-jpl/packagers/mac/commit_for_signing-issm-mac-binaries-python-3.sh	(revision 27111)
@@ -138,4 +138,6 @@
 	echo "Removing lock file from repository for signed packages"
 	svn update \
+		--trust-server-cert \
+		--non-interactive \
 		--username ${ISSM_BINARIES_REPO_USER} \
 		--password ${ISSM_BINARIES_REPO_PASS} \
@@ -156,4 +158,6 @@
 # If lock file exists, a signing build is still in process by JPL Cybersecurity
 svn update \
+	--trust-server-cert \
+	--non-interactive \
 	--username ${ISSM_BINARIES_REPO_USER} \
 	--password ${ISSM_BINARIES_REPO_PASS} \
@@ -214,4 +218,6 @@
 	sleep ${SIGNING_CHECK_PERIOD}
 	svn update \
+		--trust-server-cert \
+		--non-interactive \
 		--username ${ISSM_BINARIES_REPO_USER} \
 		--password ${ISSM_BINARIES_REPO_PASS} \
@@ -221,4 +227,6 @@
 		# Retrieve notarization lock file
 		svn update \
+			--trust-server-cert \
+			--non-interactive \
 			--username ${ISSM_BINARIES_REPO_USER} \
 			--password ${ISSM_BINARIES_REPO_PASS} \
Index: /issm/trunk-jpl/packagers/mac/complete-issm-mac-binaries-matlab.sh
===================================================================
--- /issm/trunk-jpl/packagers/mac/complete-issm-mac-binaries-matlab.sh	(revision 27110)
+++ /issm/trunk-jpl/packagers/mac/complete-issm-mac-binaries-matlab.sh	(revision 27111)
@@ -6,5 +6,5 @@
 #
 # Normally, we would put this directly into the project configuration under 
-# 'Build' -> 'Excute shell', but becasue it is a bit more involved, it is a 
+# 'Build' -> 'Execute shell', but because it is a bit more involved, it is a 
 # good idea to version it.
 #
@@ -33,10 +33,11 @@
 # Debugging:
 # - Relies on a very tight handshake with project on remote JPL Cybersecurity 
-#	Jenkins server. Debugging may be perfomed locally by running,
+#	Jenkins server. Debugging may be performed locally by running,
 #
 #		packagers/mac/sign-issm-mac-binaries-matlab.sh
 #
-#	with "ISSM_BINARIES_USER" and "ISSM_BINARIES_PASS" hardcoded to Apple 
-#	Developer credentials.
+#	with "AD_IDENTITY", "AD_USERNAME", and "ASC_PROVIDER" hardcoded to Apple 
+#	Developer credentials (make sure to also set keychain password in 
+#	"ALTOOL_PASSWORD").
 # - Removing stdout/stderr redirections to null device (> /dev/null 2>&1) can 
 #	help debug potential SVN issues.
Index: /issm/trunk-jpl/packagers/mac/complete-issm-mac-binaries-python-2.sh
===================================================================
--- /issm/trunk-jpl/packagers/mac/complete-issm-mac-binaries-python-2.sh	(revision 27110)
+++ /issm/trunk-jpl/packagers/mac/complete-issm-mac-binaries-python-2.sh	(revision 27111)
@@ -6,5 +6,5 @@
 #
 # Normally, we would put this directly into the project configuration under 
-# 'Build' -> 'Excute shell', but becasue it is a bit more involved, it is a 
+# 'Build' -> 'Execute shell', but because it is a bit more involved, it is a 
 # good idea to version it.
 #
@@ -33,10 +33,11 @@
 # Debugging:
 # - Relies on a very tight handshake with project on remote JPL Cybersecurity 
-#	Jenkins server. Debugging may be perfomed locally by running,
+#	Jenkins server. Debugging may be performed locally by running,
 #
 #		packagers/mac/sign-issm-mac-binaries-python-2.sh
 #
-#	with "ISSM_BINARIES_USER" and "ISSM_BINARIES_PASS" hardcoded to Apple 
-#	Developer credentials.
+#	with "AD_IDENTITY", "AD_USERNAME", and "ASC_PROVIDER" hardcoded to Apple 
+#	Developer credentials (make sure to also set keychain password in 
+#	"ALTOOL_PASSWORD").
 # - Removing stdout/stderr redirections to null device (> /dev/null 2>&1) can 
 #	help debug potential SVN issues.
Index: /issm/trunk-jpl/packagers/mac/complete-issm-mac-binaries-python-3.sh
===================================================================
--- /issm/trunk-jpl/packagers/mac/complete-issm-mac-binaries-python-3.sh	(revision 27110)
+++ /issm/trunk-jpl/packagers/mac/complete-issm-mac-binaries-python-3.sh	(revision 27111)
@@ -6,5 +6,5 @@
 #
 # Normally, we would put this directly into the project configuration under 
-# 'Build' -> 'Excute shell', but becasue it is a bit more involved, it is a 
+# 'Build' -> 'Execute shell', but because it is a bit more involved, it is a 
 # good idea to version it.
 #
@@ -33,10 +33,11 @@
 # Debugging:
 # - Relies on a very tight handshake with project on remote JPL Cybersecurity 
-#	Jenkins server. Debugging may be perfomed locally by running,
+#	Jenkins server. Debugging may be performed locally by running,
 #
 #		packagers/mac/sign-issm-mac-binaries-python-3.sh
 #
-#	with "ISSM_BINARIES_USER" and "ISSM_BINARIES_PASS" hardcoded to Apple 
-#	Developer credentials.
+#	with "AD_IDENTITY", "AD_USERNAME", and "ASC_PROVIDER" hardcoded to Apple 
+#	Developer credentials (make sure to also set keychain password in 
+#	"ALTOOL_PASSWORD").
 # - Removing stdout/stderr redirections to null device (> /dev/null 2>&1) can 
 #	help debug potential SVN issues.
Index: /issm/trunk-jpl/packagers/mac/transfer-issm-mac-binaries.sh
===================================================================
--- /issm/trunk-jpl/packagers/mac/transfer-issm-mac-binaries.sh	(revision 27110)
+++ /issm/trunk-jpl/packagers/mac/transfer-issm-mac-binaries.sh	(revision 27111)
@@ -76,4 +76,6 @@
 # Retrieve signed and notarized package
 svn update \
+	--trust-server-cert \
+	--non-interactive \
 	--username ${ISSM_BINARIES_REPO_USER} \
 	--password ${ISSM_BINARIES_REPO_PASS} \

Index: /issm/trunk-jpl/packagers/mac/sign-issm-mac-binaries-matlab.sh
===================================================================
--- /issm/trunk-jpl/packagers/mac/sign-issm-mac-binaries-matlab.sh	(revision 27110)
+++ /issm/trunk-jpl/packagers/mac/sign-issm-mac-binaries-matlab.sh	(revision 27111)
@@ -45,5 +45,5 @@
 #	the 'Bindings' section under a 'Username and password (separated)' binding 
 #	(requires 'Credentials Binding Plugin').
-# - For local debugging, the aformentioned credentials can be hardcoded into 
+# - For local debugging, the aforementioned credentials can be hardcoded into 
 #	the 'USERNAME' and 'PASSWORD' constants below.
 ################################################################################
@@ -109,5 +109,5 @@
 
 # # Check out copy of repository for unsigned packages
 # echo "Checking out copy of respository for unsigned packages"
 # svn checkout \
 # 	--trust-server-cert \
@@ -160,10 +160,10 @@
 
 # Sleep until notarization request response is received
-echo "Waiting for notarizaion request response"
+echo "Waiting for notarization request response"
 while [[ ! -f ${NOTARIZATION_LOGFILE_PATH}/${NOTARIZATION_LOGFILE} || ! -z $(find ${NOTARIZATION_LOGFILE_PATH} -empty -name ${NOTARIZATION_LOGFILE}) ]]; do
 	sleep 30
 done
 
-echo "Notarizaion request response received"
+echo "Notarization request response received"
 
 # Check if UUID exists in response
@@ -249,5 +249,5 @@
 
 # Check out copy of repository for signed packages
-echo "Checking out copy of respository for signed packages"
+echo "Checking out copy of repository for signed packages"
 SVN_ATTEMPT=0
 SVN_SUCCESS=0
@@ -271,5 +271,5 @@
 
 if [ ${SVN_SUCCESS} -eq 0 ]; then
-	echo "Checkout of respository for signed packages failed"
+	echo "Checkout of repository for signed packages failed"
 	exit 1
 fi
@@ -308,5 +308,5 @@
 
 	if [ ${SVN_SUCCESS} -eq 0 ]; then
-		echo "Commit to respository for signed packages failed"
+		echo "Commit to repository for signed packages failed"
 		exit 1
 	fi
@@ -331,5 +331,5 @@
 
 	if [ ${SVN_SUCCESS} -eq 0 ]; then
-		echo "Commit to respository for signed packages failed"
+		echo "Commit to repository for signed packages failed"
 		exit 1
 	fi
@@ -109,5 +109,5 @@
 
 # # Check out copy of repository for unsigned packages
-# echo "Checking out copy of respository for unsigned packages"
+# echo "Checking out copy of repository for unsigned packages"
 # svn checkout \
 # 	--trust-server-cert \
Index: /issm/trunk-jpl/packagers/mac/sign-issm-mac-binaries-python-2.sh
===================================================================
--- /issm/trunk-jpl/packagers/mac/sign-issm-mac-binaries-python-2.sh	(revision 27110)
+++ /issm/trunk-jpl/packagers/mac/sign-issm-mac-binaries-python-2.sh	(revision 27111)
@@ -45,5 +45,5 @@
 #	the 'Bindings' section under a 'Username and password (separated)' binding 
 #	(requires 'Credentials Binding Plugin').
-# - For local debugging, the aformentioned credentials can be hardcoded into 
+# - For local debugging, the aforementioned credentials can be hardcoded into 
 #	the 'USERNAME' and 'PASSWORD' constants below.
 ################################################################################
@@ -109,5 +109,5 @@
 
 # # Check out copy of repository for unsigned packages
 # echo "Checking out copy of respository for unsigned packages"
 # svn checkout \
 # 	--trust-server-cert \
@@ -170,10 +170,10 @@
 
 # Sleep until notarization request response is received
-echo "Waiting for notarizaion request response"
+echo "Waiting for notarization request response"
 while [[ ! -f ${NOTARIZATION_LOGFILE_PATH}/${NOTARIZATION_LOGFILE} || ! -z $(find ${NOTARIZATION_LOGFILE_PATH} -empty -name ${NOTARIZATION_LOGFILE}) ]]; do
 	sleep 30
 done
 
-echo "Notarizaion request response received"
+echo "Notarization request response received"
 
 # Check if UUID exists in response
@@ -259,5 +259,5 @@
 
 # Check out copy of repository for signed packages
-echo "Checking out copy of respository for signed packages"
+echo "Checking out copy of repository for signed packages"
 SVN_ATTEMPT=0
 SVN_SUCCESS=0
@@ -281,5 +281,5 @@
 
 if [ ${SVN_SUCCESS} -eq 0 ]; then
-	echo "Checkout of respository for signed packages failed"
+	echo "Checkout of repository for signed packages failed"
 	exit 1
 fi
@@ -318,5 +318,5 @@
 
 	if [ ${SVN_SUCCESS} -eq 0 ]; then
-		echo "Commit to respository for signed packages failed"
+		echo "Commit to repository for signed packages failed"
 		exit 1
 	fi
@@ -341,5 +341,5 @@
 
 	if [ ${SVN_SUCCESS} -eq 0 ]; then
-		echo "Commit to respository for signed packages failed"
+		echo "Commit to repository for signed packages failed"
 		exit 1
 	fi
@@ -109,5 +109,5 @@
 
 # # Check out copy of repository for unsigned packages
-# echo "Checking out copy of respository for unsigned packages"
+# echo "Checking out copy of repository for unsigned packages"
 # svn checkout \
 # 	--trust-server-cert \
Index: /issm/trunk-jpl/packagers/mac/sign-issm-mac-binaries-python-3.sh
===================================================================
--- /issm/trunk-jpl/packagers/mac/sign-issm-mac-binaries-python-3.sh	(revision 27110)
+++ /issm/trunk-jpl/packagers/mac/sign-issm-mac-binaries-python-3.sh	(revision 27111)
@@ -45,5 +45,5 @@
 #	the 'Bindings' section under a 'Username and password (separated)' binding 
 #	(requires 'Credentials Binding Plugin').
-# - For local debugging, the aformentioned credentials can be hardcoded into 
+# - For local debugging, the aforementioned credentials can be hardcoded into 
 #	the 'USERNAME' and 'PASSWORD' constants below.
 ################################################################################
@@ -109,5 +109,5 @@
 
 # # Check out copy of repository for unsigned packages
 # echo "Checking out copy of respository for unsigned packages"
 # svn checkout \
 # 	--trust-server-cert \
@@ -170,10 +170,10 @@
 
 # Sleep until notarization request response is received
-echo "Waiting for notarizaion request response"
+echo "Waiting for notarization request response"
 while [[ ! -f ${NOTARIZATION_LOGFILE_PATH}/${NOTARIZATION_LOGFILE} || ! -z $(find ${NOTARIZATION_LOGFILE_PATH} -empty -name ${NOTARIZATION_LOGFILE}) ]]; do
 	sleep 30
 done
 
-echo "Notarizaion request response received"
+echo "Notarization request response received"
 
 # Check if UUID exists in response
@@ -259,5 +259,5 @@
 
 # Check out copy of repository for signed packages
-echo "Checking out copy of respository for signed packages"
+echo "Checking out copy of repository for signed packages"
 SVN_ATTEMPT=0
 SVN_SUCCESS=0
@@ -281,5 +281,5 @@
 
 if [ ${SVN_SUCCESS} -eq 0 ]; then
-	echo "Checkout of respository for signed packages failed"
+	echo "Checkout of repository for signed packages failed"
 	exit 1
 fi
@@ -318,5 +318,5 @@
 
 	if [ ${SVN_SUCCESS} -eq 0 ]; then
-		echo "Commit to respository for signed packages failed"
+		echo "Commit to repository for signed packages failed"
 		exit 1
 	fi
@@ -341,5 +341,5 @@
 
 	if [ ${SVN_SUCCESS} -eq 0 ]; then
-		echo "Commit to respository for signed packages failed"
+		echo "Commit to repository for signed packages failed"
 		exit 1
 	fi
@@ -109,5 +109,5 @@
 
 # # Check out copy of repository for unsigned packages
-# echo "Checking out copy of respository for unsigned packages"
+# echo "Checking out copy of repository for unsigned packages"
 # svn checkout \
 # 	--trust-server-cert \